@@ -31,19 +31,14 @@
 
 #include <X11/Xatom.h>
 #include <gtk/gtk.h>
-#include <dirent.h>
 #include <eel/eel-glib-extensions.h>
-#include <eel/eel-gnome-extensions.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-stock-dialogs.h>
-#include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <fcntl.h>
 #include <gdk/gdkx.h>
 #include <glib/gi18n.h>
+#include <libnautilus-private/nautilus-desktop-background.h>
 #include <libnautilus-private/nautilus-desktop-icon-file.h>
-#include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-directory-notify.h>
 #include <libnautilus-private/nautilus-file-changes-queue.h>
 #include <libnautilus-private/nautilus-file-operations.h>
@@ -72,16 +67,16 @@ struct FMDesktopIconViewDetails
 	GdkWindow *root_window;
 	GtkActionGroup *desktop_action_group;
 	guint desktop_merge_id;
-	
+
 	/* For the desktop rescanning
 	 */
 	gulong delayed_init_signal;
 	guint reload_desktop_timeout;
 	gboolean pending_rescan;
+
+	NautilusDesktopBackground *background;
 };
 
-static void     fm_desktop_icon_view_init                   (FMDesktopIconView      *desktop_icon_view);
-static void     fm_desktop_icon_view_class_init             (FMDesktopIconViewClass *klass);
 static void     default_zoom_level_changed                        (gpointer                user_data);
 static gboolean real_supports_auto_layout                         (FMIconView             *view);
 static gboolean real_supports_scaling	                          (FMIconView             *view);
@@ -91,10 +86,9 @@ static void     real_merge_menus                                  (FMDirectoryVi
 static void     real_update_menus                                 (FMDirectoryView        *view);
 static gboolean real_supports_zooming                             (FMDirectoryView        *view);
 static void     fm_desktop_icon_view_update_icon_container_fonts  (FMDesktopIconView      *view);
+static void     font_changed_callback                             (gpointer                callback_data);
 
-EEL_CLASS_BOILERPLATE (FMDesktopIconView,
-		       fm_desktop_icon_view,
-		       FM_TYPE_ICON_VIEW)
+G_DEFINE_TYPE (FMDesktopIconView, fm_desktop_icon_view, FM_TYPE_ICON_VIEW)
 
 static char *desktop_directory;
 static time_t desktop_dir_modify_time;
@@ -106,12 +100,6 @@ desktop_directory_changed_callback (gpointer callback_data)
 	desktop_directory = nautilus_get_desktop_directory ();
 }
 
-static void
-lockdown_disable_command_line_changed_callback (gpointer callback_data)
-{
-	fm_directory_view_update_menus (FM_DIRECTORY_VIEW (callback_data));
-}
-
 static NautilusIconContainer *
 get_icon_container (FMDesktopIconView *icon_view)
 {
@@ -225,7 +213,7 @@ net_workarea_changed (FMDesktopIconView *icon_view,
 		nautilus_icon_container_set_margins (icon_container,
 						     0, 0, 0, 0);
 	} else {
-		screen = gdk_drawable_get_screen (GDK_DRAWABLE (window));
+		screen = gdk_window_get_screen (window);
 
 		icon_container_set_workarea (
 			icon_container, screen, workareas, length_returned / sizeof (long));
@@ -261,7 +249,23 @@ desktop_icon_view_property_filter (GdkXEvent *gdk_xevent,
 }
 
 static void
-fm_desktop_icon_view_destroy (GtkObject *object)
+real_begin_loading (FMDirectoryView *object)
+{
+	NautilusIconContainer *icon_container;
+	FMDesktopIconView *view;
+
+	view = FM_DESKTOP_ICON_VIEW (object);
+
+	icon_container = get_icon_container (view);
+	if (view->details->background == NULL) {
+		view->details->background = nautilus_desktop_background_new (icon_container);
+	}
+
+	FM_DIRECTORY_VIEW_CLASS (fm_desktop_icon_view_parent_class)->begin_loading (object);
+}
+
+static void
+fm_desktop_icon_view_dispose (GObject *object)
 {
 	FMDesktopIconView *icon_view;
 	GtkUIManager *ui_manager;
@@ -281,36 +285,35 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 					&icon_view->details->desktop_action_group);
 	}
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
-}
+	g_signal_handlers_disconnect_by_func (nautilus_icon_view_preferences,
+					      default_zoom_level_changed,
+					      icon_view);
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      font_changed_callback,
+					      icon_view);
 
-static void
-fm_desktop_icon_view_finalize (GObject *object)
-{
-	FMDesktopIconView *icon_view;
+	g_signal_handlers_disconnect_by_func (nautilus_preferences,
+					      desktop_directory_changed_callback,
+					      NULL);
 
-	icon_view = FM_DESKTOP_ICON_VIEW (object);
-	
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
-					 default_zoom_level_changed,
-					 icon_view);
+	g_signal_handlers_disconnect_by_func (gnome_lockdown_preferences,
+					      fm_directory_view_update_menus,
+					      icon_view);
 
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE,
-					 lockdown_disable_command_line_changed_callback,
-					 icon_view);
-	
-	g_free (icon_view->details);
+	if (icon_view->details->background != NULL) {
+		g_object_unref (icon_view->details->background);
+		icon_view->details->background = NULL;
+	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (fm_desktop_icon_view_parent_class)->dispose (object);
 }
 
 static void
 fm_desktop_icon_view_class_init (FMDesktopIconViewClass *class)
 {
-	G_OBJECT_CLASS (class)->finalize = fm_desktop_icon_view_finalize;
-
-	GTK_OBJECT_CLASS (class)->destroy = fm_desktop_icon_view_destroy;
+	G_OBJECT_CLASS (class)->dispose = fm_desktop_icon_view_dispose;
 
+	FM_DIRECTORY_VIEW_CLASS (class)->begin_loading = real_begin_loading;
 	FM_DIRECTORY_VIEW_CLASS (class)->merge_menus = real_merge_menus;
 	FM_DIRECTORY_VIEW_CLASS (class)->update_menus = real_update_menus;
 	FM_DIRECTORY_VIEW_CLASS (class)->supports_zooming = real_supports_zooming;
@@ -319,6 +322,8 @@ fm_desktop_icon_view_class_init (FMDesktopIconViewClass *class)
 	FM_ICON_VIEW_CLASS (class)->supports_scaling = real_supports_scaling;
 	FM_ICON_VIEW_CLASS (class)->supports_keep_aligned = real_supports_keep_aligned;
 	FM_ICON_VIEW_CLASS (class)->supports_labels_beside_icons = real_supports_labels_beside_icons;
+
+	g_type_class_add_private (class, sizeof (FMDesktopIconViewDetails));
 }
 
 static void
@@ -342,7 +347,7 @@ fm_desktop_icon_view_handle_middle_click (NautilusIconContainer *icon_container,
 	/* build an X event to represent the middle click. */
 	x_event.type = ButtonPress;
 	x_event.send_event = True;
-	x_event.display = GDK_DISPLAY ();
+	x_event.display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
 	x_event.window = GDK_ROOT_WINDOW ();
 	x_event.root = GDK_ROOT_WINDOW ();
 	x_event.subwindow = 0;
@@ -356,7 +361,7 @@ fm_desktop_icon_view_handle_middle_click (NautilusIconContainer *icon_container,
 	x_event.same_screen = True;
 	
 	/* Send it to the root window, the window manager will handle it. */
-	XSendEvent (GDK_DISPLAY (), GDK_ROOT_WINDOW (), True,
+	XSendEvent (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), GDK_ROOT_WINDOW (), True,
 		    ButtonPressMask, (XEvent *) &x_event);
 }
 
@@ -418,8 +423,9 @@ get_default_zoom_level (void)
 
 	if (!auto_storage_added) {
 		auto_storage_added = TRUE;
-		eel_preferences_add_auto_enum (NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
-					       (int *) &default_zoom_level);
+		eel_g_settings_add_auto_enum (nautilus_icon_view_preferences,
+					      NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
+					      (int *) &default_zoom_level);
 	}
 
 	return CLAMP (default_zoom_level, NAUTILUS_ZOOM_LEVEL_SMALLEST, NAUTILUS_ZOOM_LEVEL_LARGEST);
@@ -466,7 +472,8 @@ do_desktop_rescan (gpointer data)
 }
 
 static void
-done_loading (GtkObject *DirectoryView, FMDesktopIconView *desktop_icon_view)
+done_loading (NautilusDirectory *model,
+	      FMDesktopIconView *desktop_icon_view)
 {
 	struct stat buf;
 
@@ -513,11 +520,12 @@ fm_desktop_icon_view_update_icon_container_fonts (FMDesktopIconView *icon_view)
 {
 	NautilusIconContainer *icon_container;
 	char *font;
-	
+
 	icon_container = get_icon_container (icon_view);
 	g_assert (icon_container != NULL);
 
-	font = eel_preferences_get (NAUTILUS_PREFERENCES_DESKTOP_FONT);
+	font = g_settings_get_string (nautilus_desktop_preferences,
+				      NAUTILUS_PREFERENCES_DESKTOP_FONT);
 
 	nautilus_icon_container_set_font (icon_container, font);
 
@@ -531,10 +539,14 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 	GtkAllocation allocation;
 	GtkAdjustment *hadj, *vadj;
 
+	desktop_icon_view->details = G_TYPE_INSTANCE_GET_PRIVATE (desktop_icon_view,
+								  FM_TYPE_DESKTOP_ICON_VIEW,
+								  FMDesktopIconViewDetails);
+
 	if (desktop_directory == NULL) {
-		eel_preferences_add_callback (NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-					      desktop_directory_changed_callback,
-					      NULL);
+		g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
+					  G_CALLBACK(desktop_directory_changed_callback),
+					  NULL);
 		desktop_directory_changed_callback (NULL);
 	}
 
@@ -543,9 +555,6 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 	nautilus_icon_container_set_use_drop_shadows (icon_container, TRUE);
 	fm_icon_container_set_sort_desktop (FM_ICON_CONTAINER (icon_container), TRUE);
 
-	/* Set up details */
-	desktop_icon_view->details = g_new0 (FMDesktopIconViewDetails, 1);	
-
 	/* Do a reload on the desktop if we don't have FAM, a smarter
 	 * way to keep track of the items on the desktop.
 	 */
@@ -567,11 +576,11 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 	
 	gtk_widget_queue_resize (GTK_WIDGET (icon_container));
 
-	hadj = gtk_layout_get_hadjustment (GTK_LAYOUT (icon_container));
-	vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (icon_container));
+	hadj = gtk_scrollable_get_hadjustment (GTK_SCROLLABLE (icon_container));
+	vadj = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (icon_container));
 
-	eel_gtk_adjustment_set_value (hadj, 0);
-	eel_gtk_adjustment_set_value (vadj, 0);
+	gtk_adjustment_set_value (hadj, 0);
+	gtk_adjustment_set_value (vadj, 0);
 
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (desktop_icon_view),
 					     GTK_SHADOW_NONE);
@@ -594,22 +603,24 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 				 G_CALLBACK (realized_callback), desktop_icon_view, 0);
 	g_signal_connect_object (desktop_icon_view, "unrealize",
 				 G_CALLBACK (unrealized_callback), desktop_icon_view, 0);
-	
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
-				      default_zoom_level_changed,
-				      desktop_icon_view);
-	
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_DESKTOP_FONT,
-						  font_changed_callback, 
-						  desktop_icon_view, G_OBJECT (desktop_icon_view));
-	
+
+	g_signal_connect_swapped (nautilus_icon_view_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
+				  G_CALLBACK (default_zoom_level_changed),
+				  desktop_icon_view);
+
+	g_signal_connect_swapped (nautilus_desktop_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_DESKTOP_FONT,
+				  G_CALLBACK (font_changed_callback),
+				  desktop_icon_view);
+
 	default_zoom_level_changed (desktop_icon_view);
 	fm_desktop_icon_view_update_icon_container_fonts (desktop_icon_view);
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE,
-				      lockdown_disable_command_line_changed_callback,
-				      desktop_icon_view);
-
+	g_signal_connect_swapped (gnome_lockdown_preferences,
+				  "changed::" NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE,
+				  G_CALLBACK (fm_directory_view_update_menus),
+				  desktop_icon_view);
 }
 
 static void
@@ -689,15 +700,15 @@ real_update_menus (FMDirectoryView *view)
 	gboolean disable_command_line;
 	gboolean include_empty_trash;
 	GtkAction *action;
-	
+
 	g_assert (FM_IS_DESKTOP_ICON_VIEW (view));
 
-	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS, update_menus, (view));
+	FM_DIRECTORY_VIEW_CLASS (fm_desktop_icon_view_parent_class)->update_menus (view);
 
 	desktop_view = FM_DESKTOP_ICON_VIEW (view);
 
 	/* New Launcher */
-	disable_command_line = eel_preferences_get_boolean (NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE);
+	disable_command_line = g_settings_get_boolean (gnome_lockdown_preferences, NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE);
 	action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
 					      FM_ACTION_NEW_LAUNCHER_DESKTOP);
 	gtk_action_set_visible (action,
@@ -707,7 +718,7 @@ real_update_menus (FMDirectoryView *view)
 	include_empty_trash = trash_link_is_selection (view);
 	action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
 					      FM_ACTION_EMPTY_TRASH_CONDITIONAL);
-	gtk_action_set_visible (action, 
+	gtk_action_set_visible (action,
 				include_empty_trash);
 	if (include_empty_trash) {
 		label = g_strdup (_("E_mpty Trash"));
@@ -750,7 +761,7 @@ real_merge_menus (FMDirectoryView *view)
 	GtkActionGroup *action_group;
 	const char *ui;
 
-	EEL_CALL_PARENT (FM_DIRECTORY_VIEW_CLASS, merge_menus, (view));
+	FM_DIRECTORY_VIEW_CLASS (fm_desktop_icon_view_parent_class)->merge_menus (view);
 
 	desktop_view = FM_DESKTOP_ICON_VIEW (view);
 
