@@ -44,7 +44,6 @@
 #include <libnautilus-private/nautilus-file-operations.h>
 #include <libnautilus-private/nautilus-trash-monitor.h>
 #include <libnautilus-private/nautilus-icon-names.h>
-#include <libnautilus-private/nautilus-autorun.h>
 #include <libnautilus-private/nautilus-window-info.h>
 #include <libnautilus-private/nautilus-window-slot-info.h>
 #include <gio/gio.h>
@@ -401,7 +400,7 @@ compare_for_selection (NautilusPlacesSidebar *sidebar,
 {
 	int res;
 
-	res = eel_strcmp (added_uri, last_uri);
+	res = g_strcmp0 (added_uri, last_uri);
 
 	if (res == 0) {
 		/* last_uri always comes first */
@@ -410,7 +409,7 @@ compare_for_selection (NautilusPlacesSidebar *sidebar,
 		}
 		*path = gtk_tree_model_get_path (sidebar->filter_model,
 						 iter);
-	} else if (eel_strcmp (location, added_uri) == 0) {
+	} else if (g_strcmp0 (location, added_uri) == 0) {
 		if (*path == NULL) {
 			*path = gtk_tree_model_get_path (sidebar->filter_model,
 							 iter);
@@ -803,7 +802,7 @@ update_places (NautilusPlacesSidebar *sidebar)
 		g_free (tooltip);
 	}
 
-	eel_g_object_list_free (network_mounts);
+	g_list_free_full (network_mounts, g_object_unref);
 
 	/* network:// */
  	mount_uri = "network:///"; /* No need to strdup */
@@ -1673,17 +1672,17 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 
 	show_empty_trash = (uri != NULL) &&
 			   (!strcmp (uri, "trash:///"));
-	
-	eel_gtk_widget_set_shown (sidebar->popup_menu_separator_item, 
-			show_mount || show_unmount || show_eject || show_format || show_empty_trash);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_mount_item, show_mount);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_unmount_item, show_unmount);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_eject_item, show_eject);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_rescan_item, show_rescan);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_format_item, show_format);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_start_item, show_start);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_stop_item, show_stop);
-	eel_gtk_widget_set_shown (sidebar->popup_menu_empty_trash_item, show_empty_trash);
+
+	gtk_widget_set_visible (sidebar->popup_menu_separator_item,
+		      show_mount || show_unmount || show_eject || show_format || show_empty_trash);
+	gtk_widget_set_visible (sidebar->popup_menu_mount_item, show_mount);
+	gtk_widget_set_visible (sidebar->popup_menu_unmount_item, show_unmount);
+	gtk_widget_set_visible (sidebar->popup_menu_eject_item, show_eject);
+	gtk_widget_set_visible (sidebar->popup_menu_rescan_item, show_rescan);
+	gtk_widget_set_visible (sidebar->popup_menu_format_item, show_format);
+	gtk_widget_set_visible (sidebar->popup_menu_start_item, show_start);
+	gtk_widget_set_visible (sidebar->popup_menu_stop_item, show_stop);
+	gtk_widget_set_visible (sidebar->popup_menu_empty_trash_item, show_empty_trash);
 
 	/* Adjust start/stop items to reflect the type of the drive */
 	gtk_menu_item_set_label (GTK_MENU_ITEM (sidebar->popup_menu_start_item), _("_Start"));
@@ -1857,7 +1856,7 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 
 			sidebar->go_to_after_mount_flags = flags;
 
-			nautilus_file_operations_mount_volume_full (NULL, volume, FALSE,
+			nautilus_file_operations_mount_volume_full (NULL, volume,
 								    volume_mounted_cb,
 								    G_OBJECT (sidebar));
 		} else if (volume == NULL && drive != NULL &&
@@ -1992,7 +1991,7 @@ mount_shortcut_cb (GtkMenuItem           *item,
 			    -1);
 
 	if (volume != NULL) {
-		nautilus_file_operations_mount_volume (NULL, volume, FALSE);
+		nautilus_file_operations_mount_volume (NULL, volume);
 		g_object_unref (volume);
 	}
 }
